@@ -30,7 +30,6 @@ from build_harness.tools.git import (
 from ._declarations import (
     DEFAULT_CONSOLE_LOGGING_ENABLED,
     DEFAULT_FILE_LOGGING_DISABLED,
-    DEFAULT_LOG_LEVEL,
     DEFAULT_PROJECT_PATH,
     PublishOptions,
 )
@@ -114,7 +113,7 @@ def publish_flow_main(
         logging_state = LoggingState(
             disable_file_logging=DEFAULT_FILE_LOGGING_DISABLED,
             enable_console_logging=DEFAULT_CONSOLE_LOGGING_ENABLED,
-            log_level_text=DEFAULT_LOG_LEVEL,
+            log_level_text="debug",
         )
         state = CommandState(
             logging_state=logging_state,
