@@ -15,13 +15,13 @@ import sys
 
 import click
 
-from build_harness._project import acquire_source_dir
 from build_harness._utility import (
     CommandArgs,
     command_path,
     report_console_error,
     run_command,
 )
+from build_harness.project import acquire_source_dir
 
 from .code_style import FormattingError, _apply_formatting
 from .state import CommandState, ExitState
@@ -31,7 +31,6 @@ log = logging.getLogger(__name__)
 
 FLAKE8_FORMAT_CMD: CommandArgs = ["flake8", "."]
 MYPY_FORMAT_CMD: CommandArgs = ["mypy", "--show-error-codes", "."]
-PYDOCSTYLE_FORMAT_CMD: CommandArgs = ["pydocstyle", "."]
 
 VALID_ANALYSIS_OPTIONS = [
     "all",
@@ -110,14 +109,15 @@ def _run_pydocstyle(source_path: pathlib.Path, venv_path: pathlib.Path) -> None:
     Raises:
         StaticAnalysisError: If pydocstyle analysis fails.
     """
-    click.echo("pydocstyle analysis...")
-    PYDOCSTYLE_FORMAT_CMD[0] = command_path(venv_path, PYDOCSTYLE_FORMAT_CMD)
-    PYDOCSTYLE_FORMAT_CMD[-1] = str(source_path)
-    result = run_command(PYDOCSTYLE_FORMAT_CMD)
-
-    if result.returncode != 0:
-        raise PydocstyleError("pydocstyle analysis failed")
-    click.echo(click.style("pydocstyle analysis completed", fg="green"))
+    click.echo(
+        click.style(
+            "WARNING: pydocstyle analysis is deprecated and will be removed in "
+            "the next major release. Run flake8 analysis instead with "
+            "flake8-docstrings plugin",
+            fg="yellow",
+        )
+    )
+    _run_flake8(source_path, venv_path)
 
 
 def _apply_analysis(
@@ -140,7 +140,10 @@ def _apply_analysis(
     if analysis_type != "all":
         analysis_methods[analysis_type](project_path / source_dir, venv_path)
     else:
-        for this_method in analysis_methods.values():
+        # exclude deprecated `pydocstyle` analysis from `all`
+        for this_method in [
+            y for x, y in analysis_methods.items() if x != "pydocstyle"
+        ]:
             this_method(project_path / source_dir, venv_path)
 
 
@@ -156,15 +159,17 @@ def static_analysis(ctx: click.Context, analysis: str) -> None:
     """
     Run suite of Python static analysis.
 
-    The suite currently comprises "flake8", "pydocstyle" and "mypy". Formatting is
-    run before the static analysis to eliminate formatting complaints from static
-    analysis tools.
+    The suite currently comprises "flake8", "pydocstyle" and "mypy". Formatting
+    is run before the static analysis to eliminate formatting complaints from
+    static analysis tools.
     """
     try:
         command_state: CommandState = ctx.obj
 
         _apply_formatting(command_state.venv_path)
-        _apply_analysis(analysis, command_state.project_path, command_state.venv_path)
+        _apply_analysis(
+            analysis, command_state.project_path, command_state.venv_path
+        )
     except FormattingError as e:
         report_console_error(str(e))
         sys.exit(ExitState.FORMATTING_FAILED.value)
