@@ -74,7 +74,7 @@ class TestBootstrap:
     def test_default_branch(self, click_runner):
         with click_runner.isolated_filesystem():
             result = click_runner.invoke(
-                main, (self.COMMAND_BASE.copy() + ["--default-branch", "fancy"])
+                main, (self.COMMAND_BASE.copy() + ["--default-branch", "main"])
             )
 
             if result.exit_code != 0:
