@@ -11,7 +11,10 @@ import pathlib
 import tempfile
 
 from build_harness import __version__
-from build_harness.commands._release_flow import GitNotFoundError, release_flow_main
+from build_harness.commands._release_flow import (
+    GitNotFoundError,
+    release_flow_main,
+)
 from build_harness.commands.state import ExitState
 from build_harness.tools.git import TagData
 from tests.ci.support.click_runner import click_runner  # noqa: F401
@@ -82,7 +85,9 @@ class TestReleaseFlowMain:
 
     def test_bad_repo(self, click_runner):
         with tempfile.TemporaryDirectory() as this_dir:
-            result = click_runner.invoke(release_flow_main, ["--project", this_dir])
+            result = click_runner.invoke(
+                release_flow_main, ["--project", this_dir]
+            )
 
             assert result.exit_code == ExitState.BAD_REPO.value
             assert "FAILED: Invalid git repository" in result.output
@@ -90,15 +95,20 @@ class TestReleaseFlowMain:
     def test_bad_git(self, click_runner, mocker):
         mocker.patch(
             "build_harness.commands._release_flow.validate_git",
-            side_effect=GitNotFoundError("Git must be installed to use this utility"),
+            side_effect=GitNotFoundError(
+                "Git must be installed to use this utility"
+            ),
         )
         result = click_runner.invoke(release_flow_main, ["--git", "bad/path"])
 
         assert result.exit_code == ExitState.BAD_GIT_EXE.value
         assert (
-            "Git must be installed and configured to use this utility" in result.output
+            "Git must be installed and configured to use this utility"
+            in result.output
+        )
+        assert (
+            "sudo apt install -y git || sudo yum install git" in result.output
         )
-        assert "sudo apt install -y git || sudo yum install git" in result.output
 
     def test_default_branch(self, click_runner, mocker):
         expected_branch = "alternate_main"
